@@ -22,10 +22,11 @@ import shlex
 import subprocess
 import sys
 import re
+import os
 
-__author__ = 'Wangolo Joel (info@nmapper.com)'
-__version__ = '0.1.1'
-__last_modification__ = '2019/11/22'
+__author__ = 'Wangolo Joel (inquiry@nmapper.com)'
+__version__ = '1.4.9'
+__last_modification__ = '2019/12/11'
 
 
 def get_nmap_path():
@@ -68,6 +69,10 @@ def get_nmap_version():
     else:
         return output.decode('utf8').strip()
 
-if __name__ == "__main__":
-    p = get_nmap_path()
-    v = get_nmap_version()
+def user_is_root(func):
+    def wrapper(*args, **kwargs):
+        if(os.geteuid() == 0):
+            return func(*args, **kwargs)
+        else:
+            return {"error":True, "msg":"You must be root to continue!"}
+    return wrapper 
